/*
 * Copyright (C) 2014-2024 CZ.NIC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations including
 * the two.
 */

#pragma once

#include <QDateTime>
#include <QString>

#define DATE_DB_FORMAT "yyyy-MM-dd"
#define DATETIME_DB_FORMAT "yyyy-MM-dd HH:mm:ss.zzz"
#define DATETIME_QML_FORMAT "dd.MM.yyyy HH:mm:ss"
#define DATETIME_QML_FORMAT_NO_SS "dd.MM.yyyy HH:mm"

/*!
 * @brief Converts date and time from database format into QML page.
 */
QDateTime dateTimeFromDbFormat(const QString &dateTimeDbStr);

/*!
 * @brief Converts date and time from database format into desired format if
 *     possible.
 */
QString dateTimeStrFromDbFormat(const QString &dateTimeDbStr,
    const QString &tgtFmt);

/*!
 * @brief Converts datetime to database UTC datetime string.
 */
QString dateTimeToDbFormatStr(const QDateTime &dateTime);

/*!
 * @brief Converts date to format to be stored in database.
 */
QString qDateToDbFormat(const QDate &date);

/*!
 * @brief Converts date from database format into desired format if possible.
 */
QDate dateFromDbFormat(const QString &dateDbStr);

/*!
 * @brief Number of days remains to message deletion.
 *
 * @note Returns 0 if message has already deleted from ISDS or -1
 *       if the acceptance time is invalid.
 */
int remainsDaysToMsgDeletion(const QString &acceptanceDateTimeDbStr);
